**Example 1: 示例**



Input: 

```
tccli cdwch DeleteBackUpData --cli-unfold-argument  \
    --InstanceId xx \
    --BackUpJobId 0
```

Output: 
```
{
    "Response": {
        "RequestId": "xx"
    }
}
```

